function [h,q,W,T,A,c,b]= DataPbm (iscen,stag,scen)
%--------------------------------------------------------------------------
% Basic Course on Stochastic Programming, IMPA 2016
%--------------------------------------------------------------------------
% This script returns all the data of a two-stage stochastic linear
% programming problem for a given scenario iscen.
%--------------------------------------------------------------------------
%         min c'x  + \sum_{i=1}^N p_i Q(x,\xi^i)
%           s.t. Ax = b, x \geq 0,
%
%        Q(x,\xi) = min q'y
%                   s.t. Tx + Wy =h 
%                         y\geq 0 
%--------------------------------------------------------------------------
% Inputs:
% iscen -> this is the scenario's index:  from 1 up to Nscen   
% stag  -> this the stage for which the data is required: 
       % stag = 1 returns only A, c and b, the data for the 1st stage
       % stag = 2 returns only h, q, W and T the data for the 2st stage and given scenario iscen
       % stag = 0 returns all the data
% scen ->  this the matrix containing scenarios: row i provide the i-th scenario.
%
% Example: [h,q,W,T,A,c,b]= DataPbm (10,0,scen)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

m1=   30;n1=   60;m2=   40;n2=   60;
h=[];q=[];W=[];T=[];A=[];A=[];c=[];b=[];
if nargin==1,stag=0;end
if (stag==2)||(stag==0)
h=scen(iscen,:);h=h(:); 
if nargout>=2,q=[        9.860;       1.450;       6.590;       4.010;       2.850;       9.190;       5.120;       7.490;       2.250;       5.830;       1.650;       1.240;       9.800;       1.390;       4.450;       2.240;       7.070;       2.330;       5.800;       4.610;       3.140;       7.520;       6.350;       3.490;       7.030;       3.780;       4.930;       4.600;       2.950;       8.800;       6.270;       5.620;       4.980;       6.720;       7.970;       7.030;       3.560;       6.640;       7.460;       6.530;       9.020;       3.490;       9.180;       9.910;       4.910;       7.050;       3.540;       0.540;       2.050;       5.170;       7.190;       3.100;       5.490;       2.840;       7.720;       8.900;       9.400;       8.930;       8.410;       7.410;];end
if nargout>=3,I=[           27          41          59          87         100         104         105         143         162         184         197         206         208         218         241         244         246         247         252         254         267         270         314         324         327         332         339         347         350         351         353         354         364         374         380         382         403         409         413         418         435         437         441         444         478         514         519         529         531         550         552         556         571         574         579         594         627         632         641         644         645         648         654         658         659         662         665         668         684         702         704         706         709         716         746         761         762         775         792         793         799         814         820         835         847         862         872         880         885         923         937         940         942         952         953         956         985        1004        1012        1015        1017        1018        1030        1051        1065        1075        1081        1082        1090        1103        1107        1140        1175        1176        1197        1211        1231        1245        1257        1272        1277        1297        1302        1317        1322        1342        1349        1359        1367        1369        1378        1383        1411        1412        1416        1419        1420        1424        1440        1477        1489        1509        1518        1519        1520        1527        1529        1530        1533        1541        1548        1549        1551        1553        1554        1555        1556        1558        1560        1567        1619        1644        1647        1677        1679        1685        1696        1705        1706        1715        1726        1735        1752        1755        1759        1765        1766        1767        1771        1777        1822        1834        1838        1847        1848        1852        1868        1882        1892        1901        1904        1906        1909        1917        1918        1923        1931        1937        1961        1990        2035        2046        2050        2057        2066        2085        2102        2105        2107        2113        2116        2118        2156        2172        2173        2180        2184        2196        2214        2217        2219        2222        2228        2232        2241        2266        2272        2285        2286        2307        2315        2327        2339        2349        2376        2378        2383        2385        2387        2391];
nonzeros=[       -0.100       9.400      -5.300      -0.500      -3.600       4.000      -7.000       1.700      -7.700      -3.900       6.100       5.400      -9.400      -9.500      -2.800      -4.300      -2.700       8.200       2.200      -4.900       1.350      -3.200       3.500      -0.100       5.100      -2.300      -7.700      -4.100      -7.400       6.800      -6.500      -7.600       3.500      -0.700      -7.200       6.200       2.500       5.500       8.300       2.000       4.000       3.900      -1.400      -5.400       2.100       0.100       2.950       1.800      -2.850       0.200      -0.300       3.800       4.850       7.400       2.000       1.900      -0.100       3.350      -5.100       8.900      -7.500       4.900      -3.100       2.900       0.900      -4.600       4.000      -8.800      -5.800       3.200      -6.100      -7.700       6.900       1.800       7.000      -5.500      -7.000       4.100       1.500      -5.500       0.100      -1.500      -1.900       8.300       5.200      -4.000      -2.850       5.100       3.500      -8.500      -9.600      -4.800       6.600      -6.900      18.500      -1.200       1.600      -1.400       9.600      -9.400      -1.000       8.600       3.600       3.900      -2.300       0.900       6.700       5.500      -6.000       4.700      -2.350       5.900       5.300      -2.000      -0.300     -14.350      -0.800       0.600       4.600      -1.150      -3.400       5.100      -4.000      -0.700       7.200       3.400      -1.700      -8.200      -8.500      -1.000       3.600       1.100       1.150       3.400       8.100       5.800      -7.700       2.200      -3.000       5.600      -5.700      -8.300       6.200       1.900      -0.300      -7.700      -0.600       6.700      -1.100      -2.900       3.100      -4.300      -2.000      -8.700      -8.000      -3.800       0.600      -8.000      -1.800       3.800       7.600       4.600       7.500      -9.800       3.250      -6.600       3.200      -2.600       2.100       3.400       5.100      -3.700       7.900       2.300       3.700       3.900       1.800      -4.400       4.850       1.400     -13.700      10.100       2.500       0.400       4.500      -0.600       4.000      -5.700       4.600       2.900      -8.700      -0.400       4.200       4.700      -3.400       6.000       2.450      -1.700      -5.700       6.800       1.750      -7.200      -0.700      -6.200      -3.600       4.700       6.000       2.900       0.250       2.200       2.950       0.600      -0.350     -16.900      -7.200      19.300       8.600      -7.600       2.800       7.400      -0.900       0.900       1.700       3.100       4.400       2.600       3.250       1.400       2.700      -3.100     -14.550      -9.100      -2.400       3.200      -9.300      -7.600      -7.500       3.400       8.150      -4.000];
W=zeros(m2,n2);W(I)=nonzeros;end
if nargout>=4,I=[            2          41          44          52          56          59         104         121         123         126         129         130         133         134         135         138         141         143         154         156         186         203         205         209         210         212         217         221         223         230         234         235         236         240         245         247         251         252         254         260         262         264         268         269         270         272         277         278         279         280         281         283         284         285         286         288         289         291         292         295         297         298         299         300         301         303         305         306         310         311         314         317         319         323         324         325         328         332         338         339         340         341         342         347         352         353         354         355         356         361         366         371         372         373         375         378         381         383         396         401         404         405         406         409         410         411         414         415         416         418         419         422         423         426         433         435         439         440         444         445         449         451         452         459         474         481         484         485         487         488         489         493         496         497         498         511         514         517         518         519         520         521         522         528         532         533         534         535         538         539         543         546         549         554         557         559         560         562         569         570         574         575         576         578         580         581         587         588         589         590         595         597         599         601         609         612         619         636         641         642         651         652         653         660         662         665         669         670         671         672         673         675         677         680         681         721         723         725         729         736         739         741         750         756         761         764         765         769         772         779         783         809         812         843         845         851         855         859         874         876         880         881         883         885         886         889         891         892         894         895         896         901         902         903         915         916         917         920         923         924         929         933         935         939         941         943         950         954         960         961         972         979        1001        1004        1005        1007        1009        1011        1013        1016        1021        1026        1033        1037        1040        1041        1046        1054        1056        1062        1064        1065        1067        1068        1069        1070        1074        1075        1077        1078        1079        1084        1085        1087        1090        1092        1093        1094        1095        1097        1098        1101        1102        1103        1112        1113        1116        1119        1120        1121        1123        1124        1125        1129        1131        1136        1137        1139        1150        1156        1170        1201        1202        1203        1204        1205        1206        1208        1210        1211        1218        1220        1223        1225        1226        1228        1230        1231        1232        1235        1236        1239        1241        1244        1252        1259        1281        1285        1289        1291        1292        1296        1301        1310        1314        1316        1321        1322        1323        1327        1334        1336        1337        1338        1340        1344        1345        1347        1351        1352        1353        1355        1356        1362        1363        1366        1368        1374        1375        1377        1379        1382        1383        1388        1391        1394        1396        1398        1399        1401        1404        1405        1406        1408        1411        1412        1414        1416        1417        1420        1424        1433        1434        1435        1436        1438        1440        1441        1443        1446        1447        1448        1451        1453        1454        1455        1457        1464        1467        1471        1472        1473        1478        1481        1484        1489        1491        1495        1496        1499        1501        1503        1516        1524        1529        1539        1543        1567        1572        1574        1575        1580        1581        1586        1588        1590        1591        1592        1594        1595        1596        1599        1603        1604        1605        1608        1609        1610        1611        1612        1614        1618        1619        1620        1622        1623        1626        1631        1633        1636        1637        1644        1647        1648        1649        1652        1655        1656        1659        1662        1665        1666        1668        1671        1672        1674        1677        1681        1684        1691        1703        1721        1724        1729        1730        1732        1734        1735        1736        1746        1750        1754        1756        1757        1759        1761        1763        1764        1766        1769        1771        1773        1774        1775        1776        1779        1790        1795        1796        1797        1799        1801        1806        1807        1817        1819        1820        1822        1824        1826        1828        1829        1830        1835        1836        1838        1840        1852        1882        1885        1886        1889        1890        1891        1894        1896        1898        1900        1902        1903        1909        1913        1914        1919        1921        1922        1923        1928        1930        1935        1939        1940        1941        1942        1943        1945        1946        1947        1953        1954        1963        1965        1966        1969        1970        1971        1973        1975        1976        1978        1982        1983        1990        1995        1996        2001        2004        2005        2009        2011        2016        2021        2023        2034        2044        2081        2083        2089        2090        2091        2092        2093        2096        2101        2102        2103        2106        2112        2113        2114        2115        2116        2117        2118        2120        2121        2124        2126        2129        2130        2131        2132        2133        2134        2137        2139        2140        2142        2143        2150        2154        2155        2159        2160        2161        2163        2164        2165        2167        2168        2169        2171        2172        2173        2177        2178        2179        2180        2182        2183        2186        2190        2192        2194        2195        2196        2197        2199        2201        2211        2212        2216        2217        2219        2223        2230        2234        2235        2236        2241        2243        2244        2246        2247        2249        2250        2253        2258        2259        2262        2263        2264        2267        2269        2278        2281        2285        2289        2291        2295        2297        2300        2302        2304        2305        2306        2307        2313        2314        2316        2319        2323        2324        2326        2331        2332        2333        2335        2355        2356        2361        2363        2364        2365        2366        2367        2369        2370        2371        2372        2373        2374        2377        2381        2382        2383        2384        2385        2388        2389        2392        2393        2395        2396        2397];
nonzeros=[        4.000       2.000      -7.300      -5.100      -8.600      -1.800       2.600       5.200       4.000       9.900      -6.700       8.800      -7.900       7.300      -1.300       1.200      -7.900       4.100      -0.900      -6.600       4.000      -1.400      -1.800      -1.100      -4.900       4.400       2.000      -7.500       0.800       7.600       3.300      -9.400      -9.700       3.600       9.600       6.900      -6.400       0.800      -3.300       9.800      -9.700      -8.800       1.000      -8.100       5.600      -2.400      -9.400      -2.400      -4.500      -7.200       2.100      -7.600      -3.800       6.900       6.100       1.700       6.700      -6.300       8.500      -9.600      -7.100      -9.100       3.500      -6.100      -1.600      -4.500       7.200      -1.400       2.000       2.000      -8.800       8.300       1.200       4.300       2.900       6.900      -7.700       9.100      -4.600      -3.600       4.900       4.300       5.300      -5.000       5.600      -3.100       1.100      -8.700       3.900       2.400       7.000      -3.400      -3.200       5.400       5.500       1.700       8.000      -6.700       4.400      -1.200       1.500       7.100       4.300       4.300      -0.400      -1.000      -7.700      -5.600      -5.900       1.800      -4.200       1.600      -4.900       9.400      -9.200       8.700       9.400       0.700       3.600      -3.800      -4.400       6.800       0.800       1.400      -2.100      -3.300      -3.400       0.900       1.000      -4.600       5.700       8.400       0.400      -1.100       9.800       4.500       9.500       9.600      -4.000      -6.000       9.200      -0.200       2.400      -5.000       3.400       6.500      -3.400      -0.900       2.200       2.700       7.100      -7.000      -0.800       4.100       3.500      -8.500      -3.300       0.200      -0.600       5.300       3.500       2.500      -3.300       7.700      -7.100       0.500       1.200       8.300       9.800      -8.800      -0.500       5.400       3.300       9.400      -4.700      -0.300      -4.100      -7.600      -4.400       5.600       4.900      -4.100      -2.400      -3.400       8.400      -5.200       9.400      -8.800      -7.400      -7.400       3.800      -5.400       8.000      -6.100       6.600       2.200      -4.800      -5.100       5.200       1.400      -4.000       4.900       6.200      -7.500      -5.100       0.800      -5.400       0.400       3.700       8.600       7.500       6.500       0.800       6.900       3.600       4.900       3.500       0.500      -0.300      -5.600      -7.500       0.800       0.400       8.600      -9.500      -0.400      -6.300      -0.800      -6.600       0.400      -8.600      -2.900       2.500      -7.900       1.100       7.300       5.400      -0.600       9.700       2.400      -4.300      -3.100      -6.700      -6.200       0.200      -4.400      -2.100       7.500       3.700       2.500       7.600       2.000       4.900      -3.600      -1.000       9.000       6.500      -0.800       9.300       2.300      -0.500       8.400       9.700      -8.300      -9.000      -4.500       4.500      -9.600      -9.800       6.200      -3.700       1.400       6.500      -8.700       7.800      -8.300      -5.400       8.100       0.500      -0.600       4.700      -5.700      -6.400      -4.500       4.900      -1.200      -0.400       6.400      -3.900      -6.900      -7.900       1.900       0.500      -0.600      -6.400       7.400      -4.800       6.900      -1.400       0.100       5.100       3.400      -0.700      -9.500      -1.900       1.600       0.200       7.800      -6.100      -2.300       2.200       6.100      -2.800       7.200       1.100       7.600      -0.200       7.200       8.500       9.800      -1.200      -3.900      -6.300      -8.300       5.200      -7.900       7.800       7.500       2.900       5.400       2.800      -9.200      -1.700       8.400       1.800       4.500      -2.400      -4.200      -5.000      -6.100       0.600      -9.400      -5.800       3.400      -1.800      -4.500      -5.200       7.100       7.500       2.200       9.600       9.700      -2.300       2.900       8.200      -4.000      -0.900       0.100       7.100      -9.100      -4.200      -3.500      -7.700      -2.200       4.600      -3.800       8.600      -5.900      -7.300      -9.400      -6.100       1.100       1.300       3.700      -7.500      -4.400       2.200       8.600       2.800       4.300      -2.000      -0.800      -4.800       5.500      -2.600      -3.000      -3.000       6.600       4.000      -6.200      -3.100      -4.200      -2.400       3.900       3.300       1.700       7.500      -5.800       8.900      -3.400       4.600      -3.800       8.800       6.100       5.000      -4.100       6.900      -0.500       3.500       1.700      -6.400      -9.600      -5.200       7.000       1.700       1.400       3.600       1.800       8.900       4.500      -6.200       9.300      -7.000       9.500      -1.300       2.600      -6.200      -0.400       5.600      -3.700       9.400       1.900       6.000       9.200       6.000       0.900       0.400       8.800      -2.800       7.000      -4.900       4.600       9.300      -2.900       4.100      -3.800      -3.400       5.400       9.800      -3.900      -4.200      -6.100       6.800      -0.900      -1.300      -5.600       9.000      -8.800       1.400       8.600      -4.800      -8.400       0.500      -8.600       9.700       1.800       3.400       6.500      -3.000       1.400      -0.600      -4.200       1.900      -1.400      -5.700      -3.700       1.900      -2.200       1.400      -3.800       2.400      -1.000      -6.800       8.000      -7.600      -8.800      -1.100      -3.600      -7.200       2.300       1.900      -2.800      -0.400      -1.800      -4.400      -2.700       8.900       7.700      -2.800       9.200      -7.800       9.200      -1.700       4.800      -0.200       5.900      -6.200      -4.700       9.700      -7.300       3.600      -7.200      -6.800       6.500      -5.600       2.300      -9.400       9.300      -9.300      -9.100       7.800       2.000       3.700      -7.000       6.400       0.600      -1.500      -7.400       9.300       2.400       7.000       0.400      -3.600       3.800       2.100      -7.600      -4.500      -9.300      -3.200       1.400      -3.100      -2.800      -2.100      -3.200       3.500       6.800       1.100      -5.100      -1.400       2.400      -5.500       3.700      -1.200       7.600      -8.600       9.500       3.900      -8.700      -2.200       2.700       8.300       4.500      -0.100       4.000      -7.200       4.500       7.100      -1.600      -9.700       0.900       1.600       0.700      -2.200      -4.700      -1.000      -9.200       0.700      -7.200      -3.900       9.800       8.100      -2.400      -7.200       1.000      -0.600      -6.700      -9.600       7.800      -9.000      -7.000       6.600      -9.700      -0.100      -6.200      -5.400       6.500       7.200      -4.200       8.500       4.600       1.400       7.800       5.300       5.400      -3.900       6.100      -3.900       3.200      -1.600      -8.700       8.100       7.300       2.500       3.800      -0.600      -4.200      -0.800      -9.100      -0.400       2.400      -5.400      -5.800      -7.600      -2.200      -4.100      -5.200       2.700      -5.500       0.900      -5.200      -4.500       2.000       6.100       1.200       0.400       0.300       2.000       0.200      -7.300      -7.500      -5.600      -8.300       3.200       7.700       8.900      -2.100      -5.400      -2.200      -6.600      -5.300       5.600      -2.700      -2.100       1.000       5.700       6.200       4.700      -2.700       0.100      -9.500      -9.200       8.700      -0.300      -3.200       8.600      -0.900      -1.800      -5.100      -5.000       7.400       3.500      -6.000      -0.900       0.700       6.800      -5.200      -6.100       7.600       2.300       9.100       3.900       2.300       9.600       6.900       6.500      -8.200       6.300       7.900       2.700       2.900      -6.500       9.500      -6.500       3.500      -2.800       6.300      -0.900       7.700      -7.500      -2.700      -3.800      -6.500      -6.600       3.600       7.200      -8.400      -4.200       8.800       5.400       6.300       3.800       2.900       7.000      -7.000      -7.900       2.600      -6.800       4.400       9.200       0.400       8.900      -2.100       4.300      -4.200      -1.000];
T=zeros(m2,n1);T(I)=nonzeros;end
end
if (stag==1)||(stag==0)
if nargout>=5,I=[            1           3           6           9          13          17          18          19          23          24          25          26          28          29          31          32          33          34          36          38          39          40          41          42          43          44          45          48          49          50          51          52          53          55          58          59          60          61          62          63          64          65          66          67          68          71          72          73          75          77          81          82          83          85          86          87          88          89          92          93          94          95          98          99         101         102         104         106         110         113         114         118         119         120         122         123         124         125         126         127         128         129         131         132         133         134         135         140         146         147         152         153         157         158         159         160         161         164         171         173         175         176         177         178         179         180         195         211         213         218         223         228         230         233         235         236         237         238         239         241         242         248         249         252         253         255         258         259         260         262         263         266         268         269         270         271         275         277         278         280         281         283         284         285         288         289         290         295         296         297         299         301         303         304         307         308         309         310         314         315         317         318         320         321         322         325         326         331         333         338         343         348         349         357         358         386         392         393         396         399         400         401         402         403         404         405         407         408         409         410         414         415         417         418         419         421         423         428         433         438         439         445         446         447         448         453         458         463         468         470         475         476         477         478         481         482         483         484         485         486         490         492         496         499         503         505         506         508         509         510         511         516         527         529         530         533         534         535         536         537         538         539         542         543         544         545         548         550         551         552         553         558         559         562         565         566         567         568         576         601         602         603         604         606         610         613         616         618         619         620         621         623         624         628         630         631         633         638         643         648         656         657         658         661         662         663         667         669         672         673         676         678         681         682         683         685         686         687         689         691         693         697         698         699         700         702         703         704         705         709         710         712         714         715         716         717         719         720         721         722         724         725         726         727         728         729         732         733         739         740         741         742         744         745         756         758         759         761         763         764         767         769         770         771         772         773         774         775         777         778         780         781         782         783         785         788         789         791         792         793         796         802         804         806         807         808         810         811         813         818         823         828         838         841         842         843         845         846         847         848         849         850         851         852         853         855         856         857         858         859         860         863         864         866         868         869         870         871         876         877         878         879         883         888         889         890         893         894         896         897         899         901         903         906         907         908         910         914         918         919         920         923         924         925         928         929         930         933         934         935         937         941         943         944         945         948         950         951         953         956         957         958         960         963         968         973         978         987         988         998        1028        1048        1053        1056        1067        1068        1069        1073        1076        1078        1083        1086        1087        1089        1092        1095        1097        1098        1099        1103        1104        1105        1107        1108        1109        1118        1123        1128        1137        1142        1143        1145        1146        1148        1152        1153        1155        1156        1158        1160        1166        1167        1168        1169        1170        1174        1176        1178        1179        1180        1181        1185        1186        1187        1189        1190        1191        1192        1194        1195        1198        1202        1204        1205        1206        1207        1210        1212        1215        1220        1222        1223        1224        1225        1226        1229        1230        1231        1232        1233        1236        1237        1238        1239        1240        1242        1243        1244        1245        1247        1250        1253        1256        1257        1259        1261        1262        1263        1265        1266        1268        1270        1279        1281        1282        1283        1284        1285        1286        1289        1290        1294        1295        1297        1299        1301        1302        1303        1304        1305        1307        1309        1310        1312        1314        1316        1317        1335        1352        1353        1356        1362        1363        1364        1365        1366        1368        1369        1372        1375        1377        1378        1379        1380        1384        1385        1386        1388        1390        1392        1393        1394        1396        1397        1403        1405        1407        1408        1409        1410        1411        1417        1418        1419        1420        1424        1425        1427        1430        1433        1434        1436        1437        1438        1439        1448        1458        1467        1468        1474        1475        1477        1479        1480        1481        1482        1483        1484        1485        1487        1489        1491        1492        1495        1500        1501        1503        1506        1507        1508        1509        1510        1512        1513        1515        1517        1518        1519        1520        1523        1524        1525        1526        1527        1528        1538        1548        1558        1563        1566        1568        1580        1583        1586        1587        1588        1589        1594        1634        1651        1652        1653        1655        1658        1659        1660        1661        1663        1664        1666        1675        1677        1678        1679        1680        1681        1687        1688        1689        1695        1704        1705        1710        1713        1718        1723        1728        1729        1730        1733        1735        1737        1738        1741        1743        1746        1748        1752        1753        1757        1760        1763        1764        1765        1766        1767        1790];
nonzeros=[       -2.800       4.600      -2.100       6.000       6.200      -6.400      -1.800       9.600      -7.900      -2.100      -5.900       2.200      -0.300      -4.300       1.200      -1.600       9.400       2.700       7.600       3.300      -1.300      -7.900      -0.600      -3.100      -1.200      -2.200      -9.700      -6.500      -0.700      -6.000       3.900       6.300      -6.700       4.900      -2.100       1.000      -1.000       4.800      -8.900      -1.200      -0.500       7.300      -3.500       8.000      -1.200       7.200      -5.600       8.800       6.200      -3.900      -0.500      -6.700       0.900       0.300      -3.900      -3.100       3.400      -5.500      -9.000       9.000      -5.700       6.300       7.700      -4.800      -6.400      -9.600       9.100      -6.300       6.800       5.800      -9.700       2.300       4.300       6.600       1.900       9.400      -7.300      -4.400      -0.500      -8.000       3.000      -9.200       2.700       1.800      -8.800      -1.200      -3.300      -0.100      -9.400      -5.100      -1.000       6.700      -2.800       3.400      -6.300       5.200       3.300      -2.800       5.300      -5.700       0.500      -3.600      -9.000      -1.900       4.300       4.600      -9.800      -6.200       6.700      -0.400      -1.800       7.400       0.400       1.600       4.800       7.000      -5.400       1.600       2.400       9.400      -5.700      -5.000       4.800       7.800       8.500       9.300       6.800      -9.300       9.400       2.300      -3.100      -1.500      -5.100       4.300      -9.000       5.300      -6.800       0.800       6.300       9.300      -6.500       4.700      -9.500       1.200       3.300       7.400       6.900      -7.700       4.300       0.400       9.000       2.600      -8.700       0.500      -9.500       3.600      -6.200      -4.900       9.500       3.400      -3.000       3.400      -5.500       0.500       9.300       0.200      -8.300      -6.400       7.500       7.700      -7.100       8.200       6.100       2.700      -0.900      -7.100       4.900      -8.400      -5.000       9.100      -8.500      -4.700      -1.900       5.300      -4.300       9.000       4.600      -7.800       9.600      -5.300       5.300      -6.800       6.200       5.600      -8.000      -3.700      -9.000       9.900      -7.100       7.700       5.900       3.700       1.800       6.000      -8.400       4.900       1.900       9.100       1.200       2.400      -0.900       8.800       7.200       9.300      -3.600      -9.100       6.200      -2.800       8.900      -0.500      -6.400      -1.600      -3.300      -0.900       2.400       3.300      -6.500       8.900       3.300       4.600       4.000      -6.100       5.400      -1.800       9.400      -5.100       0.200      -3.900       8.800       0.400      -3.800      -0.300      -5.000       1.500      -5.000       5.700      -9.300       4.200       4.300       9.000       5.100      -2.000       3.800       3.300       8.700      -3.800       2.600       4.100      -7.500       1.800       3.100       4.000      -0.900       4.400       8.200      -8.200      -3.400      -3.700       4.500      -3.600       1.000       7.800      -6.400       9.500       5.900      -9.700       1.800       5.700       8.200      -4.100      -1.000       3.300       3.100      -9.800      -4.800      -8.700      -5.400       4.100       3.100       9.500      -8.000      -0.400      -2.700      -9.100       9.200      -6.900      -2.900       4.000      -2.700       7.300      -5.400      -5.300       5.000      -5.000       0.600       9.300      -3.000      -4.200      -9.100       9.500      -3.800       4.200       6.300      -5.300       2.100       6.400      -1.200      -9.100       4.800       6.500       3.300      -2.800       3.300      -0.500      -6.200      -5.800      -2.000      -2.300       1.400       3.200      -4.600      -6.400      -5.300      -4.400       8.300      -3.100       6.500       3.600      -0.700       7.900      -0.800       9.500       6.300      -8.800      -9.200      -9.500      -3.000      -2.300      -2.500       7.500      -9.200       4.300       1.800      -0.800       2.600      -9.600       3.300       6.900       7.400      -7.000      -7.100      -8.800       3.600       0.600       7.200      -3.100       2.900       7.000       5.000       2.200      -8.100      -6.200      -3.200       3.400      -3.800      -6.100       6.600      -8.000       9.800      -6.300       7.000      -6.700       4.900      -8.100      -4.600       7.000      -2.000      -7.000      -9.100      -6.000      -9.300       8.500       0.800       9.700      -0.500      -6.200       8.300       8.000      -4.200       5.300       9.200       7.900      -8.000      -1.100       0.400       7.700       0.200       1.900       0.400       0.500       1.600      -0.200       7.900      -3.100       2.800       1.400      -3.600      -9.700      -1.300       3.500       6.800      -8.900       1.200      -2.500      -1.400      -4.200      -9.300       1.100       6.300       1.800      -4.500      -2.100      -4.300      -1.500       5.500      -4.900       0.400      -6.500       4.000      -0.300       0.300       4.000      -9.800      -6.300       0.800       3.300       0.100      -8.700       5.100      -7.100       0.400       1.500      -5.100      -1.100      -1.000      -7.500      -7.500      -1.600       1.300      -3.100      -2.700       5.000      -1.600      -8.200       8.300       6.700      -1.200       5.400      -7.600      -6.000       0.100       6.600       7.100      -0.700      -3.600      -5.300      -7.200       3.800      -5.400       8.400      -1.100       8.200       8.700       7.200       8.500      -9.700       4.900      -0.600       8.700      -3.100       9.000       7.700       2.800      -5.700      -6.000       8.100       1.100      -4.700      -8.800      -8.000       3.300      -7.000      -1.400      -3.800      -1.800       8.600       6.900      -7.900      -1.300      -6.200      -5.500       5.600       6.200      -9.700      -7.400       3.500       1.000      -5.500      -7.500      -3.500       4.700      -9.500      -7.500      -5.600      -7.400      -7.200       0.500      -7.600       8.300      -7.400      -3.700       5.300       9.800       4.300       5.300      -8.000       5.900       7.300      -7.100      -6.400      -7.800       2.900      -9.700      -6.300       3.600      -5.000       9.500       2.700      -8.400      -3.700      -9.200       5.800       9.500       1.100       5.600       9.200      -7.500      -9.300       0.200       0.900      -9.000      -6.700      -2.200       2.500       9.500      -9.400       1.900       5.700       4.700      -7.600      -5.200       4.900       6.600       1.400       9.600      -5.600       5.900      -1.100      -4.600       3.500       9.000      -7.200      -0.300       1.400      -2.000      -8.700      -8.100       0.600      -5.000       9.500      -9.200      -5.000       6.200      -6.300       2.800      -7.300       6.700       0.400      -2.500       8.800       7.300      -8.700       5.400      -6.900      -4.900       3.600      -1.700       9.600       2.100      -4.500       1.700      -4.900       3.000       8.800       2.900       9.500      -7.900      -3.200      -3.600      -3.600      -0.800      -1.100       2.700       5.300      -8.500      -0.300      -5.900      -8.000       6.300      -2.900      -4.800      -0.800       4.800      -2.600      -3.600       2.800      -3.700       3.400       3.200      -5.000       5.800      -0.400       6.200      -1.700       0.600      -7.500       0.300       6.500      -2.500      -9.400       1.000       1.100       1.000       4.500       6.100       8.800       5.000      -9.600      -2.100      -6.300       7.700      -7.200      -7.400      -8.800      -9.100      -5.700       1.800       1.400       0.400       4.000       5.500       7.300       0.300       2.700       1.900       8.800       3.400      -4.000      -0.200      -5.000      -4.400       2.500      -6.300      -6.000      -7.100      -5.400       4.100      -5.200      -4.500       1.300      -1.800       8.800      -4.700      -0.900      -9.100      -0.500      -1.700      -3.900       3.400       3.700      -0.700       4.800      -3.100      -6.500       9.000       6.900       5.000       9.100       7.200      -6.300      -6.800       5.800      -1.700      -4.800      -1.800       0.100      -1.800       0.700       6.500       0.700      -5.100      -7.300       6.000       8.300       6.700       8.800       8.000];
A=zeros(m1,n1);A(I)=nonzeros;end
if nargout>=6,c=[        0.300;       0.200;       0.000;      -0.100;      -1.900;      -0.100;       0.000;       0.400;       0.800;       0.800;       0.100;       0.600;      -0.100;       0.700;       0.500;       1.600;      -0.100;       0.500;      -0.200;      -0.100;       0.000;       0.400;      -1.100;       0.100;      -0.700;       0.000;      -0.800;      -0.500;      -0.900;       1.200;      -0.200;      -0.500;       0.100;      -0.500;       0.000;      -0.800;      -0.200;      -0.600;       2.200;      -0.700;       0.000;       1.100;      -0.200;       0.300;       0.000;      -1.600;       0.200;       0.800;      -0.400;      -0.200;      -0.600;      -0.200;       1.100;      -0.200;       0.000;      -2.200;      -0.100;       1.700;       0.300;       0.100;];end
if nargout>=7,b=[       -5.910;       0.760;       1.650;      -1.780;       1.710;      -0.790;      -1.340;       5.830;       1.690;       0.420;      -1.200;      -2.430;       0.480;       1.210;      -0.370;      -2.560;       0.410;       1.130;       3.620;      -1.970;       0.680;       1.230;      -2.060;      -0.010;       1.900;      -2.600;      -0.610;       3.460;       0.050;      -0.100;];end
end
return